@@ -274,19 +274,27 @@ sub is_authorized {
         return 1;
     }
 
-    # login bypass
-    $meta->set('META_LOGIN_BYPASS_STATE', 0) if not defined $meta->META_LOGIN_BYPASS_STATE;
-    return 1 if $site->MFILE_WWW_BYPASS_LOGIN_DIALOG and $meta->META_LOGIN_BYPASS_STATE;
-    if ( $site->MFILE_WWW_BYPASS_LOGIN_DIALOG and not $meta->META_LOGIN_BYPASS_STATE ) {
-        $log->notice("Bypassing login dialog! Using default credentials");
-        $session->{'ip_addr'} = $remote_addr;
-        $session->{'last_seen'} = time;
-        my $bypass_result = $self->_login_dialog( {
-            'nam' => $site->MFILE_WWW_DEFAULT_LOGIN_CREDENTIALS->{'nam'},
-            'pwd' => $site->MFILE_WWW_DEFAULT_LOGIN_CREDENTIALS->{'pwd'},
-        } );
-        $meta->set('META_LOGIN_BYPASS_STATE', 1);
-        return $bypass_result;
+    # bypass login dialog?
+    if ( $site->MFILE_WWW_BYPASS_LOGIN_DIALOG ) {
+        $log->warn( "Bypassing login dialog! Using default credentials" );
+        #
+        # since the credentials are set in the configuration file, we only
+        # need to check them once - the result of this check is placed in
+        # META_LOGIN_BYPASS_STATE
+        #
+        if ( not defined $meta->META_LOGIN_BYPASS_STATE ) {
+            $meta->set('META_LOGIN_BYPASS_STATE', 0);
+            $session->{'ip_addr'} = $remote_addr;
+            $session->{'last_seen'} = time;
+            my $bypass_status = $self->validate_user_credentials( {
+                'nam' => $site->MFILE_WWW_DEFAULT_LOGIN_CREDENTIALS->{'nam'},
+                'pwd' => $site->MFILE_WWW_DEFAULT_LOGIN_CREDENTIALS->{'pwd'},
+            } );
+            if ( $bypass_status->level() eq 'OK' ) {
+                $meta->set('META_LOGIN_BYPASS_STATE', 1);
+            }
+        }
+        return $meta->META_LOGIN_BYPASS_STATE;
     }
 
     # unauthorized session
@@ -597,6 +605,20 @@ sub _require_js {
 
 =head2 login_status
 
+Once the username and password are known (either from C<process_post> via the
+login AJAX request generated by the login dialog, or from the site
+configuration via the MFILE_WWW_BYPASS_LOGIN_DIALOG mechanism), the
+C<validate_user_credentials> method is called. That method is implemented by
+the derived application, so it can validate user credentials however it likes.
+The C<validate_user_credentials> method is then expected to call this method -
+C<login_status> - to generate a status object from the results of the user
+credentials validation.
+
+Now, C<App::MFILE::WWW> does expect the C<validate_user_credentials> method to
+provide the results of user credentials validation in a peculiar format,
+hinging on the argument C<$code>, where a value of 200 indicates successful
+validation and any other value indicates a failure.
+
 =cut
 
 sub login_status {
