@@ -237,13 +237,65 @@ define ([
             return month;
         }, // intToMonth
 
+        isTimeRangeAfterTime = function (tr, t) {
+            var b, e, trh, trm, th, tm;
+            [b, e] = tr.split('-');
+            [trh, trm] = b.split(':');
+            [th, tm] = t.split(':');
+            trh = parseInt(trh, 10);
+            trm = parseInt(trm, 10);
+            th = parseInt(th, 10);
+            tm = parseInt(tm, 10);
+            if (trh > th) {
+                return true;
+            }
+            if (trh < th) {
+                return false;
+            }
+            // trh === th
+            if (trm > tm) {
+                return true;
+            }
+            return false;
+        }, // isTimeRangeAfterTime
+
+        isTimeWithinTimeRange = function (t, tr) {
+            var b, e, t, trbh, treh, trbm, trem, th, tm;
+            [b, e] = tr.split('-');
+            [trbh, trbm] = b.split(':');
+            [treh, trem] = e.split(':');
+            [th, tm] = t.split(':');
+            trbh = parseInt(trbh, 10);
+            trbm = parseInt(trbm, 10);
+            treh = parseInt(treh, 10);
+            trem = parseInt(trem, 10);
+            th = parseInt(th, 10);
+            tm = parseInt(tm, 10);
+            if (th === trbh && tm === trbm) {
+                return true;
+            }
+            if (th === treh && tm === trem) {
+                return false;
+            }
+            t = parseFloat(th + '.' + tm);
+            b = parseFloat(trbh + '.' + trbm);
+            e = parseFloat(treh + '.' + trem);
+            if (t > b && t < e) {
+                return true;
+            }
+            return false;
+        }, // isTimeWithinTimeRange
+
         minutesToTime = function (m) {
             console.log("Entering minutesToTime() with argument", m);
             var quotient,
                 remainder;
-            if (m < 0 || m > 1440) {
+            if (m < 0) {
                 return null;
             }
+            if (m > 1440) {
+                m = 1440;
+            }
             quotient = String(Math.floor(m/60));
             remainder = String(m % 60);
             console.log("Quotient is", quotient);
@@ -455,10 +507,16 @@ define ([
 
         canonicalizeTimeRange: canonicalizeTimeRange,
 
+        canonicalizeTimeRangeOffset: canonicalizeTimeRangeOffset,
+
         intToDay: intToDay,
 
         intToMonth: intToMonth,
 
+        isTimeRangeAfterTime: isTimeRangeAfterTime,
+
+        isTimeWithinTimeRange: isTimeWithinTimeRange,
+
         minutesToTime: minutesToTime,
 
         monthToInt: monthToInt,
