@@ -70,7 +70,7 @@ define ([
 
             opts = lib.objectify(opts);
             opts['inputId'] = ('inputId' in opts) ? opts.inputId : null;
-            opts['resultLine'] = ('resultLine' in opts) ? opts.resultLine : null;
+            opts['resultLine'] = ('resultLine' in opts) ? opts.resultLine : "&nbsp";
             opts['_start'] = ('_start' in opts) ? opts.start : true;
             opts['_restart'] = ('_restart' in opts) ? opts._restart : false;
             opts['_start'] = opts._restart ? true : opts._start;
@@ -251,7 +251,7 @@ define ([
 
         // unwind stack until given target is reached
         // optional object to pass to start()
-        unwindToTarget = function (tname, obj) {
+        unwindToTarget = function (tname, newObj, opts) {
             var i, tgt;
             console.log("Unwinding the stack to target " + tname);
             for (i = _stack.length; i > 0; i -= 1) {
@@ -259,9 +259,9 @@ define ([
                 if (tgt.name === tname) {
                    break;
                 }
-                popWithoutStart();
+                popWithoutStart(newObj, opts);
             }
-            tgt.start(obj);
+            tgt.start(newObj, opts);
         },
         
         unwindToFlag = function () {
