@@ -110,7 +110,9 @@ define ([
                     dmenuSubmit(dmn);
                 } else if (event.keyCode === 9) {
                     event.preventDefault();
-                }
+                } else if (event.keyCode === 27) {
+                    stack.pop();
+                } // end of function - don't put anything after this line
             };
         },
 
@@ -187,8 +189,16 @@ define ([
                 if (! evt.shiftKey) {
                     mmKeyListenerVetEntry(evt, n, elid);
                 }
+            } else if (evt.keyCode === 27) {
+                var xtgt = stack.getXTarget();
+                if (typeof xtgt === "string") {
+                    stack.unwindToTarget(xtgt);
+                    return null;
+                } else {
+                    stack.pop();
+                    return null;
+                }
             }
-
         },
         mmSubmit = function (obj) {
             console.log("Entering mmSubmit with object", obj);
@@ -523,12 +533,14 @@ define ([
             var dfo = target.pull(dfn);
             return function (state, opts) {
                 console.log('Entering start method of target ' + dfn);
-                var i,
+                var entry,
+                    i,
                     populateArray = [];
                 if (typeof opts !== 'object') {
                     opts = {};
                 }
                 opts.resultLine = ('resultLine' in opts) ? opts.resultLine : "&nbsp";
+                opts.resultLine = (opts.resultLine === null) ? "&nbsp" : opts.resultLine;
                 opts.inputId = ('inputId' in opts) ? opts.inputId : null;
                 coreLib.displayResult(opts.resultLine);
                 // determine dform "state" (i.e. starting content of form entries)
@@ -540,14 +552,19 @@ define ([
                 $('#mainarea').html(dfo.source(state));
                 // assemble array of entries with "populate" property
                 for (i = 0; i < dfo.entriesRead.length; i += 1) {
-                    if (dfo.entriesRead[i].hasOwnProperty("populate")) {
-                        populateArray.push(dfo.entriesRead[i].populate);
+                    entry = dfo.entriesRead[i];
+                    if (entry.hasOwnProperty("populate")) {
+                        if (typeof entry.populate === 'function') {
+                            populateArray.push(entry.populate);
+                        } else {
+                            console.log("CRITICAL ERROR: bad populate property in entry " + entry.name);
+                        }
                     }
                 }
                 // call first populate function to trigger sequential,
                 // asynchronous population of all entries with "populate" property
                 if (populateArray.length > 0) {
-                    populate(populateArray);
+                    populate.bootstrap(populateArray);
                 }
                 // listen for user input in form
                 dformListen(dfn, state, opts.inputId);
@@ -586,22 +603,6 @@ define ([
             };
         }, // dnotice
 
-        dtable: function (dtn) {
-            var dto = target.pull(dtn);
-            return function (state, opts) {
-                // state is a array of objects to be displayed as a table
-                coreLib.clearResult();
-                console.log('Starting new ' + dtn + ' dtable');
-                if (! state) {
-                    state = stack.getState();
-                }
-                console.log('The dataset is', state);
-                $('#mainarea').html(dto.source(state));
-                $('#result').text('Displaying table with ' + coreLib.genObjStr(state.length));
-                dtableListen(dto);
-            };
-        }, // dtable
-
         drowselect: function (drsn) {
             var drso = target.pull(drsn);
             if (drsn) {
@@ -632,6 +633,24 @@ define ([
 
         drowselectListen: drowselectListen,
 
+        dtable: function (dtn) {
+            var dto = target.pull(dtn);
+            return function (state, opts) {
+                // state is a array of objects to be displayed as a table
+                coreLib.clearResult();
+                console.log('Starting new ' + dtn + ' dtable');
+                if (! state) {
+                    state = stack.getState();
+                }
+                console.log('The dataset is', state);
+                $('#mainarea').html(dto.source(state));
+                $('#result').text('Displaying table with ' + coreLib.genObjStr(state.length));
+                dtableListen(dto);
+            };
+        }, // dtable
+
+        // export key listener so we can send events to it from outside of this module
+        // (for testing automation purposes)
         mmKeyListener: mmKeyListener,
 
     }
